pub struct PySnapshotMetadata { /* private fields */ }Trait Implementations
sourceimpl Clone for PySnapshotMetadata
impl Clone for PySnapshotMetadata
sourcefn clone(&self) -> PySnapshotMetadata
fn clone(&self) -> PySnapshotMetadata
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for PySnapshotMetadata
impl Debug for PySnapshotMetadata
sourceimpl From<SnapshotMetadata> for PySnapshotMetadata
impl From<SnapshotMetadata> for PySnapshotMetadata
sourcefn from(val: SnapshotMetadata) -> Self
fn from(val: SnapshotMetadata) -> Self
Converts to this type from the input type.
sourceimpl HasPyGilRef for PySnapshotMetadata
impl HasPyGilRef for PySnapshotMetadata
sourcetype AsRefTarget = PyCell<PySnapshotMetadata>
type AsRefTarget = PyCell<PySnapshotMetadata>
Utility type to make Py::as_ref work.
sourceimpl PyClass for PySnapshotMetadata
impl PyClass for PySnapshotMetadata
sourceimpl PyClassImpl for PySnapshotMetadata
impl PyClassImpl for PySnapshotMetadata
sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
sourcetype ThreadChecker = SendablePyClass<PySnapshotMetadata>
type ThreadChecker = SendablePyClass<PySnapshotMetadata>
This handles following two situations: Read more
sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
sourceimpl<'a, 'py> PyFunctionArgument<'a, 'py> for &'a PySnapshotMetadata
impl<'a, 'py> PyFunctionArgument<'a, 'py> for &'a PySnapshotMetadata
sourceimpl<'a, 'py> PyFunctionArgument<'a, 'py> for &'a mut PySnapshotMetadata
impl<'a, 'py> PyFunctionArgument<'a, 'py> for &'a mut PySnapshotMetadata
sourceimpl PyTypeInfo for PySnapshotMetadata
impl PyTypeInfo for PySnapshotMetadata
sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
sourcefn type_object(py: Python<'_>) -> &PyType
fn type_object(py: Python<'_>) -> &PyType
👎Deprecated since 0.21.0:
PyTypeInfo::type_object will be replaced by PyTypeInfo::type_object_bound in a future PyO3 versionReturns the safe abstraction over the type object.
sourcefn type_object_bound(py: Python<'_>) -> Bound<'_, PyType>
fn type_object_bound(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
sourcefn is_type_of(object: &PyAny) -> bool
fn is_type_of(object: &PyAny) -> bool
👎Deprecated since 0.21.0:
PyTypeInfo::is_type_of will be replaced by PyTypeInfo::is_type_of_bound in a future PyO3 versionChecks if
object is an instance of this type or a subclass of this type.sourcefn is_type_of_bound(object: &Bound<'_, PyAny>) -> bool
fn is_type_of_bound(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.sourcefn is_exact_type_of(object: &PyAny) -> bool
fn is_exact_type_of(object: &PyAny) -> bool
👎Deprecated since 0.21.0:
PyTypeInfo::is_exact_type_of will be replaced by PyTypeInfo::is_exact_type_of_bound in a future PyO3 versionChecks if
object is an instance of this type.impl DerefToPyAny for PySnapshotMetadata